MenuBorderStyleType
===================

.. autoclass:: consolemenu.format.MenuBorderStyleType

    .. autoattribute:: MenuBorderStyleType.ASCII_BORDER
    .. autoattribute:: MenuBorderStyleType.LIGHT_BORDER
    .. autoattribute:: MenuBorderStyleType.HEAVY_BORDER
    .. autoattribute:: MenuBorderStyleType.DOUBLE_LINE_BORDER
    .. autoattribute:: MenuBorderStyleType.HEAVY_OUTER_LIGHT_INNER_BORDER
    .. autoattribute:: MenuBorderStyleType.DOUBLE_LINE_OUTER_LIGHT_INNER_BORDER




